package com.mortals.xhx.module.goview.service.impl;
import com.mortals.framework.model.PageInfo;
import com.mortals.xhx.module.goview.model.*;
import com.mortals.xhx.module.goview.service.GoviewMasterplateDataService;
import com.mortals.xhx.module.goview.service.GoviewProjectDataService;
import com.mortals.xhx.module.goview.service.GoviewProjectService;
import org.apache.commons.collections4.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.mortals.framework.service.impl.AbstractCRUDServiceImpl;
import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.Context;
import com.mortals.xhx.module.goview.dao.GoviewMasterplateDao;
import com.mortals.xhx.module.goview.service.GoviewMasterplateService;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
* GoviewMasterplateService
* 模板表 service实现
*
* @author zxfei
* @date 2023-04-16
*/
@Service("goviewMasterplateService")
public class GoviewMasterplateServiceImpl extends AbstractCRUDServiceImpl<GoviewMasterplateDao, GoviewMasterplateEntity, Long> implements GoviewMasterplateService {

    @Autowired
    private GoviewProjectDataService goviewProjectDataService;
    @Autowired
    private GoviewProjectService goviewProjectService;
    @Autowired
    private GoviewMasterplateDataService goviewMasterplateDataService;

    @Override
    protected void saveBefore(GoviewMasterplateEntity entity, Context context) throws AppException {
        this.validData(entity, context);
        entity.setState(-1);
    }

    @Override
    protected void findAfter(GoviewMasterplateEntity params, PageInfo pageInfo, Context context, List<GoviewMasterplateEntity> list) throws AppException {
        if(CollectionUtils.isNotEmpty(list)){
            for(GoviewMasterplateEntity item:list){
                item.setProjectName(item.getMasterplateName());
            }
        }
    }

    @Override
    protected void removeAfter(Long[] ids, Context context, int result) throws AppException {
        List<Long> masterplateIdList = new ArrayList<>();
        for(Long id:ids){
            masterplateIdList.add(id);
        }
        List<GoviewMasterplateDataEntity> list = goviewMasterplateDataService.find(new GoviewMasterplateDataQuery().masterplateIdList(masterplateIdList));
        List<Long> dataIds = new ArrayList<>();
        for(GoviewMasterplateDataEntity item:list){
            dataIds.add(item.getId());
        }
        goviewMasterplateDataService.remove(dataIds.toArray(new Long[dataIds.size()]),context);
    }

    @Override
    public void useMasterplate(Long masterplateId, Context context) throws AppException {
        GoviewMasterplateEntity masterplateEntity = this.get(masterplateId);
        if(masterplateEntity==null){
            throw new AppException("模板ID不正确，无对应数据");
        }
        GoviewProjectEntity projectEntity = new GoviewProjectEntity();
        projectEntity.setProjectName(masterplateEntity.getMasterplateName());
        projectEntity.setIndexImage(masterplateEntity.getIndexImage());
        projectEntity.setRemarks(masterplateEntity.getRemarks());
        projectEntity.setState(-1);
        if(context!=null && context.getUser()!=null) {
            projectEntity.setCustomerId(context.getUser().getId());
            projectEntity.setCreateUserId(projectEntity.getCustomerId());
        }
        projectEntity.setCreateTime(new Date());
        projectEntity = goviewProjectService.save(projectEntity);
        GoviewMasterplateDataEntity masterplateDataEntity = goviewMasterplateDataService.selectOne(new GoviewMasterplateDataQuery().masterplateId(masterplateEntity.getId()));
        if(masterplateDataEntity!=null){
            GoviewProjectDataEntity projectDataEntity = new GoviewProjectDataEntity();
            projectDataEntity.setProjectId(projectEntity.getId());
            projectDataEntity.setContent(masterplateDataEntity.getContent());
            projectDataEntity.setCreateUserId(projectEntity.getCreateUserId());
            projectDataEntity.setCreateTime(projectEntity.getCreateTime());
            goviewProjectDataService.save(projectDataEntity);
        }
    }
}