package com.mortals.xhx.module.goview.service.impl;

import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.Context;
import com.mortals.framework.service.impl.AbstractCRUDServiceImpl;
import com.mortals.xhx.module.goview.dao.GoviewProjectDao;
import com.mortals.xhx.module.goview.model.*;
import com.mortals.xhx.module.goview.service.GoviewMasterplateDataService;
import com.mortals.xhx.module.goview.service.GoviewMasterplateService;
import com.mortals.xhx.module.goview.service.GoviewProjectDataService;
import com.mortals.xhx.module.goview.service.GoviewProjectService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
* GoviewProjectService
* 项目 service实现
*
* @author zxfei
* @date 2023-04-13
*/
@Service("goviewProjectService")
public class GoviewProjectServiceImpl extends AbstractCRUDServiceImpl<GoviewProjectDao, GoviewProjectEntity, Long> implements GoviewProjectService {

    @Autowired
    private GoviewProjectDataService goviewProjectDataService;
    @Autowired
    private GoviewMasterplateService goviewMasterplateService;
    @Autowired
    private GoviewMasterplateDataService goviewMasterplateDataService;

    @Override
    protected void saveBefore(GoviewProjectEntity entity, Context context) throws AppException {
        this.validData(entity, context);
        entity.setState(-1);
    }

    @Override
    protected void removeAfter(Long[] ids, Context context, int result) throws AppException {
        List<Long> projectIdList = new ArrayList<>();
        for(Long id:ids){
            projectIdList.add(id);
        }
        List<GoviewProjectDataEntity> list = goviewProjectDataService.find(new GoviewProjectDataQuery().projectIdList(projectIdList));
        List<Long> dataIds = new ArrayList<>();
        for(GoviewProjectDataEntity item:list){
            dataIds.add(item.getId());
        }
        goviewProjectDataService.remove(dataIds.toArray(new Long[dataIds.size()]),context);
    }

    @Override
    public void publishMasterplate(Long projectId, Context context) throws AppException {
        GoviewProjectEntity projectEntity = this.get(projectId);
        if(projectEntity == null){
            throw new AppException("项目id不正确，无此项目数据");
        }
        GoviewMasterplateEntity masterplateEntity = new GoviewMasterplateEntity();
        masterplateEntity.setCustomerId(projectEntity.getCustomerId());
        masterplateEntity.setMasterplateName(projectEntity.getProjectName());
        masterplateEntity.setIndexImage(projectEntity.getIndexImage());
        masterplateEntity.setRemarks(projectEntity.getRemarks());
        if(context!=null && context.getUser()!=null) {
            masterplateEntity.setCreateUserId(context.getUser().getId());
        }
        masterplateEntity.setCreateTime(new Date());
        masterplateEntity = goviewMasterplateService.save(masterplateEntity);
        GoviewProjectDataEntity projectDataEntity = goviewProjectDataService.selectOne(new GoviewProjectDataQuery().projectId(projectId));
        if(projectDataEntity!=null){
            GoviewMasterplateDataEntity masterplateDataEntity = new GoviewMasterplateDataEntity();
            masterplateDataEntity.setMasterplateId(masterplateEntity.getId());
            masterplateDataEntity.setContent(projectDataEntity.getContent());
            masterplateDataEntity.setCreateUserId(masterplateEntity.getCreateUserId());
            masterplateDataEntity.setCreateTime(masterplateEntity.getCreateTime());
            goviewMasterplateDataService.save(masterplateDataEntity);
        }
    }
}