package com.mortals.xhx.module.help.service.impl;

import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.Context;
import com.mortals.framework.model.PageInfo;
import com.mortals.framework.service.impl.AbstractCRUDServiceImpl;
import com.mortals.xhx.common.code.EvaluateType;
import com.mortals.xhx.common.utils.StringUtils;
import com.mortals.xhx.module.help.dao.HelpDao;
import com.mortals.xhx.module.help.model.HelpEntity;
import com.mortals.xhx.module.help.model.HelpEvaluateEntity;
import com.mortals.xhx.module.help.service.HelpEvaluateService;
import com.mortals.xhx.module.help.service.HelpService;
import org.apache.commons.collections4.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
* HelpService
* 帮助信息 service实现
*
* @author zxfei
* @date 2022-06-28
*/
@Service("helpService")
public class HelpServiceImpl extends AbstractCRUDServiceImpl<HelpDao, HelpEntity, Long> implements HelpService {

    @Autowired
    private HelpEvaluateService helpEvaluateService;

    @Override
    protected HelpEntity findBefore(HelpEntity entity, PageInfo pageInfo, Context context) throws AppException {
        if(StringUtils.isNotEmpty(entity.getQuery())){
            StringBuffer condition = new StringBuffer("%");
            condition.append(entity.getQuery()).append("%");
            entity.setContent(condition.toString());
        }
        return entity;
    }

    @Override
    protected void findAfter(HelpEntity params, PageInfo pageInfo, Context context, List<HelpEntity> list) throws AppException {
        if(CollectionUtils.isNotEmpty(list)) {
            list.stream().forEach(item -> {
                HelpEvaluateEntity query = new HelpEvaluateEntity();
                query.setHelpId(item.getId());
                List<HelpEvaluateEntity> evaluateEntities = helpEvaluateService.find(query);
                if(CollectionUtils.isNotEmpty(evaluateEntities)){
                    Map<Integer, List<HelpEvaluateEntity>> map = evaluateEntities.stream().collect(Collectors.groupingBy(HelpEvaluateEntity::getEvaluateType));
                    item.setUseful(CollectionUtils.isNotEmpty(map.get(EvaluateType.USEFUL.getValue()))?map.get(EvaluateType.USEFUL.getValue()).size():0);
                    item.setUseless(CollectionUtils.isNotEmpty(map.get(EvaluateType.USELESS.getValue()))?map.get(EvaluateType.USELESS.getValue()).size():0);
                }else {
                    item.setUseful(0);
                    item.setUseless(0);
                }
            });
        }
    }
}